@@ -17,7 +17,7 @@ def read_driven_docs_file(root_dir):
         else:
             interface.initialize(os.path.join(root_dir, filepath), debug_output='line_feed')
             print 'docdriven: initializing - '+os.path.join(root_dir, filepath)
-            test_case = testcase.init_DocDrivenTestCase(interface.driven_down_doc)
+            test_case = testcase.init_DocDrivenTestCase(interface.driven_doc)
             test_suite = unittest.TestLoader().loadTestsFromTestCase(test_case)
             print 'docdriven: running unittest'
             test_suite_result = unittest.TestResult()
