@@ -554,7 +554,9 @@ def initialize(doc_filepath, debug_output=None):
     print_feed=False
     line_feed=False
     file_feed=False
-    if debug_output == 'line_feed':
+    if debug_output is None:
+        pass
+    elif debug_output == 'line_feed':
         line_feed=True
     elif debug_output == 'file_feed':
         file_feed=True
@@ -564,6 +566,7 @@ def initialize(doc_filepath, debug_output=None):
         print 'Unrecognized debug_output selection.'
         print 'Must be one of: "line_feed", "file_feed", or "file_line_feed"'
         print 'continuing with no debug_output'
+        pass
 
     if print_feed:
         print '@@@@@@@@@@@@@@@@@@@@@@@@@ dd FEED @@@@@@@@@@@@@@@@@@@@@@@@@'
